<?php
/* 
Plugin Name: Nofollow Case by Case 
Plugin URI: http://www.fob-marketing.de/marketing-blog-184-wordpress-nofollow-seo-plugin-nofollow-case-by-case.html 
Description: Nofollow Case by Case is a follow plugin for WordPress but allows you to selectively apply rel="nofollow" to comment links and comment author links. Use "<a href="http://www.fob-marketing.de/marketing-seo-blog/nfcbc-seo-plugin-add-on.html">NFCBC SEO Plugin Add-on</a>" for better comment management. Compare with <a href="http://www.fob-marketing.de/marketing-seo-blog/nfcbc-seo-light-the-light-version-of-nofollow-case-by-case.html">NFCBC SEO Light</a> for other plugin options.
Version: 1.2.0.1
Author: Oliver Bockelmann (fob marketing)
Author URI: http://www.fob-marketing.de/
Update Server: http://wordpress.org/extend/plugins/nofollow-case-by-case/
Min WP Version: 2.0.7
Max WP Version: 2.8
*/

/*

** Nofollow Case by Case, v. 1.2, 23-05-2007 | Copyright (c) 2007 fob marketing, Hamburg (All rights reserved). 
** This plugin is free software. The plugin is provided "as is" without any warranty. 
** The plugin is GPL Compatible (See http://www.gnu.org/licenses/gpl.html for details.) 

== Plugin Features == 

  * Strip nofollow from comment links (default). 
  * Selectively apply nofollow to any comment link you do not like to support. 
  * Selectively apply nofollow to any comment author link you do not like to support. 
  * Choose if you like to open your comment links in a new window or not (target="_blank" option)

== Installation == 

  0. If you want your links to be opened in a new window change the default option in line 58. 
  1. Upload `nofollow_case_by_case.php` to the `/wp-content/plugins/` directory 
  2. Activate the plugin through the 'Plugins' menu in WordPress 

  Enjoy! 

== How it works == 

If you recognize a link within your comments that you do not want to support

  1. open the comment 
  2. edit '/dontfollow' to that link and 
  3. safe it like that. 

This is an example how you can modify the link: http://www.example.com/dontfollow 

== What happens after modifying the link? == 

The link will automatically be changed from: <a href='http://www.example.com/'> to: <a href='http://www.example.com/' rel='nofollow'>
Now the major search engines will not follow this link anymore and in the result the page will not receive any pagerank from you. 
Doing so you might have protected yourself against loosing search engine trust rank. Trust rank could be lost if you promote spammers 
on your own website. If you don`t want to delete those links use nofollow for them. 

*/ 


/* ***** Choose "$blank_option = 1" if you want your comment links to be opened in a new window using target="_blank": ***** */ 

$blank_option = 0; 

/* ****************************************  You do not have to change anything else  ************************************** */


if ($blank_option == 0) {

	function make_normal_clickable($ret) {
		$ret = ' ' . $ret;
		/* In testing, the WordPress Team found arrays to be faster, so we make use of them from now on: */ 
		$ret = preg_replace(
			array(
				/* First two lines make sure that links get a nofollow tag if we want so by adding /dontfollow */
				'#([\s>])([\w]+?://[\w\#$%&~/.\-;:=,?@\[\]+]*)/(dontfollow)#is',
				'#([\s>])((www|ftp)\.[\w\#$%&~/.\-;:=,?@\[\]+]*)/(dontfollow)#is',
				'#([\s>])([\w]+?://[\w\#$%&~/.\-;:=,?@\[\]+]*)#is',
				'#([\s>])((www|ftp)\.[\w\#$%&~/.\-;:=,?@\[\]+]*)#is',
				'#([\s>])([a-z0-9\-_.]+)@([^,< \n\r]+)#i'),
			array(
				'$1<a href="$2" rel="nofollow">$2</a>',
				'$1<a href="http://$2" rel="nofollow">$2</a>',
				'$1<a href="$2">$2</a>',
				'$1<a href="http://$2">$2</a>',
				'$1<a href="mailto:$2@$3">$2@$3</a>'),$ret);
		/* Make sure that all dontfollow-links where stripped: */
		$ret = preg_replace("/\/dontfollow\"/","\" rel=\"nofollow\"",$ret);
		/* This one is not in an array because we need it to run last, for cleanup of accidental links within links */
		$ret = preg_replace("#(<a( [^>]+?>|>))<a [^>]+?>([^>]+?)</a></a>#i", "$1$3</a>",$ret);
		$ret = trim($ret);
		return $ret;
	}

	function strip_nofollow($ret) {
		$ret = preg_replace("/ rel='external nofollow'/","",$ret);
		$ret = preg_replace("/ rel=\"external nofollow\"/","",$ret);
		$ret = preg_replace("/ rel='nofollow'/","",$ret);
		$ret = preg_replace("/ rel=\"nofollow\"/","",$ret);
		return $ret;
	}

	function make_author_url_nofollow($ret) {
		$ret = preg_replace("/\/dontfollow'/","' rel=\"nofollow\"",$ret);
		$ret = preg_replace("/\/dontfollow\"/","\" rel=\"nofollow\"",$ret);
		return $ret;
	}

} else {

	function make_normal_clickable($ret) {
		$ret = ' ' . $ret;
		/* In testing, the WordPress Team found arrays to be faster, so we make use of them from now on: */
		$ret = preg_replace(
			array(
				/* First two lines make sure that links get a nofollow tag if we want so by adding /dontfollow */
				'#([\s>])([\w]+?://[\w\#$%&~/.\-;:=,?@\[\]+]*)/(dontfollow)#is',
				'#([\s>])((www|ftp)\.[\w\#$%&~/.\-;:=,?@\[\]+]*)/(dontfollow)#is',
				'#([\s>])([\w]+?://[\w\#$%&~/.\-;:=,?@\[\]+]*)#is',
				'#([\s>])((www|ftp)\.[\w\#$%&~/.\-;:=,?@\[\]+]*)#is',
				'#([\s>])([a-z0-9\-_.]+)@([^,< \n\r]+)#i'),
			array(
				'$1<a href="$2" rel="nofollow" target="_blank">$2</a>',
				'$1<a href="http://$2" rel="nofollow" target="_blank">$2</a>',
				'$1<a href="$2" target="_blank">$2</a>',
				'$1<a href="http://$2" target="_blank">$2</a>',
				'$1<a href="mailto:$2@$3">$2@$3</a>'),$ret);
		/* Make sure that all dontfollow-links where stripped: */
		$ret = preg_replace("/\/dontfollow\"/","\" rel=\"nofollow\" target=\"_blank\"",$ret);
		/* This one is not in an array because we need it to run last, for cleanup of accidental links within links */
		$ret = preg_replace("#(<a( [^>]+?>|>))<a [^>]+?>([^>]+?)</a></a>#i", "$1$3</a>",$ret);
		$ret = trim($ret);
		return $ret;
	}

	function strip_nofollow($ret) {
		$ret = preg_replace("/ rel='external nofollow'/"," target=\"_blank\"",$ret);
		$ret = preg_replace("/ rel=\"external nofollow\"/"," target=\"_blank\"",$ret);
		$ret = preg_replace("/ rel='nofollow'/"," target=\"_blank\"",$ret);
		$ret = preg_replace("/ rel=\"nofollow\"/"," target=\"_blank\"",$ret);
		return $ret;
	}

	function make_author_url_nofollow($ret) {
		$ret = preg_replace("/\/dontfollow'/","' rel=\"nofollow\"",$ret);
		$ret = preg_replace("/\/dontfollow\"/","\" rel=\"nofollow\"",$ret);
		return $ret;
	}

}

remove_filter('pre_comment_content', 'wp_rel_nofollow', 15);
remove_filter('comment_text', 'make_clickable', 9);
// remove_filter('comment_text', 'make_clickable');
add_filter('comment_text', 'make_normal_clickable', 18);
add_filter('get_comment_author_link', 'strip_nofollow', 19);
add_filter('get_comment_author_link', 'make_author_url_nofollow', 20);
?>